#include "atlas_misc.h"
#ifndef PFYDIST
   #define PFYDIST 24
#endif
#ifndef PFXDIST
   #define PFXDIST 0
#endif
#ifndef PFADIST
   #define PFADIST 0
#endif

#if !defined(ATL_3DNow) && !defined(ATL_SSE1) && \
    (PFADIST != 0 || PFXDIST != 0 || PFYDIST != 0)
   #include "atlas_prefetch.h"
#endif

#if defined(ATL_3DNow) || defined(ATL_SSE1)
   #ifndef PFIY
      #define PFIY prefetchnta
   #endif
   #ifndef PFIX
      #define PFIX prefetchnta
   #endif
   #ifndef PFIA
      #ifdef ATL_3DNow
         #define PFIA prefetchw
      #else
         #define PFIA prefetcht0
      #endif
   #endif
#endif
/*
 * X & A are prefetched in M loop PF[A,X]DIST (in bytes) ahead
 */
#if PFADIST == 0                /* flag for no prefetch */
   #define prefA(mem)
#else
   #if defined(ATL_3DNow) || defined(ATL_SSE1)
      #define prefA(mem) __asm__ __volatile__ \
         (Mstr(PFIA) " %0" : : "m" (*(((char *)(mem))+PFADIST)))
   #else
      #if PFLVL == 2
         #define prefA(mem) ATL_pfl2W(((char*)mem)+PFADIST)
      #else
         #define prefA(mem) ATL_pfl1W(((char*)mem)+PFADIST)
      #endif
   #endif
#endif
#if PFXDIST == 0                /* flag for no prefetch */
   #define prefX(mem)
#else
   #if defined(ATL_3DNow) || defined(ATL_SSE1)
      #define prefX(mem) __asm__ __volatile__ \
         (Mstr(PFIX) " %0" : : "m" (*(((char *)(mem))+PFXDIST)))
   #else
      #if PFLVL == 2
         #define prefX(mem) ATL_pfl2R(((char*)mem)+PFXDIST)
      #else
         #define prefX(mem) ATL_pfl1R(((char*)mem)+PFXDIST)
      #endif
   #endif
#endif
/*
 * Y is prefetched in N-loop, and always fetches next NU piece
 */
#if PFYDIST == 0                /* flag for no prefetch */
   #define prefY(mem)
#else
   #if defined(ATL_3DNow) || defined(ATL_SSE1)
      #define prefY(mem) \
         __asm__ __volatile__ (Mstr(PFIY) " %0" : : "m" (*(((char *)(mem)))))
   #else
      #if PFLVL == 2
         #define prefY(mem) ATL_pfl2R(mem)
      #else
         #define prefY(mem) ATL_pfl1R(mem)
      #endif
   #endif
#endif
#ifndef ATL_CINT
   #define ATL_CINT const int
#endif
#ifndef ATL_INT
   #define ATL_INT int
#endif
void ATL_UGERK(ATL_CINT M, ATL_CINT N, const float *X, const float *Y, 
               float *A, ATL_CINT lda)
/*
 * 64x24 unrolled r1_c.
 * Extracted from ATLAS/tune/blas/gemv/atlas-l2g.base
 */
{
   ATL_CINT N24=(N/24)*24, M64=(M/64)*64, lda24=lda*24;
   ATL_INT j;

   for (j=N24; j; j -= 24, A += lda24, Y += 24)
   {
      float *A0=A, *A1=A0+lda, *A2=A1+lda, *A3=A2+lda, *A4=A3+lda, *A5=A4+lda,
            *A6=A5+lda, *A7=A6+lda, *A8=A7+lda, *A9=A8+lda, *A10=A9+lda,
            *A11=A10+lda, *A12=A11+lda, *A13=A12+lda, *A14=A13+lda,
            *A15=A14+lda, *A16=A15+lda, *A17=A16+lda, *A18=A17+lda,
            *A19=A18+lda, *A20=A19+lda, *A21=A20+lda, *A22=A21+lda,
            *A23=A22+lda;
      const register float y0=Y[0], y1=Y[1], y2=Y[2], y3=Y[3], y4=Y[4], y5=Y[5],
                           y6=Y[6], y7=Y[7], y8=Y[8], y9=Y[9], y10=Y[10],
                           y11=Y[11], y12=Y[12], y13=Y[13], y14=Y[14],
                           y15=Y[15], y16=Y[16], y17=Y[17], y18=Y[18],
                           y19=Y[19], y20=Y[20], y21=Y[21], y22=Y[22],
                           y23=Y[23];
      ATL_INT i;
      prefY(Y+24+24-1);
      for (i=0; i < M64; i += 64)
      {
         const register float x0=X[i+0], x1=X[i+1], x2=X[i+2], x3=X[i+3],
                              x4=X[i+4], x5=X[i+5], x6=X[i+6], x7=X[i+7],
                              x8=X[i+8], x9=X[i+9], x10=X[i+10], x11=X[i+11],
                              x12=X[i+12], x13=X[i+13], x14=X[i+14],
                              x15=X[i+15], x16=X[i+16], x17=X[i+17],
                              x18=X[i+18], x19=X[i+19], x20=X[i+20],
                              x21=X[i+21], x22=X[i+22], x23=X[i+23],
                              x24=X[i+24], x25=X[i+25], x26=X[i+26],
                              x27=X[i+27], x28=X[i+28], x29=X[i+29],
                              x30=X[i+30], x31=X[i+31], x32=X[i+32],
                              x33=X[i+33], x34=X[i+34], x35=X[i+35],
                              x36=X[i+36], x37=X[i+37], x38=X[i+38],
                              x39=X[i+39], x40=X[i+40], x41=X[i+41],
                              x42=X[i+42], x43=X[i+43], x44=X[i+44],
                              x45=X[i+45], x46=X[i+46], x47=X[i+47],
                              x48=X[i+48], x49=X[i+49], x50=X[i+50],
                              x51=X[i+51], x52=X[i+52], x53=X[i+53],
                              x54=X[i+54], x55=X[i+55], x56=X[i+56],
                              x57=X[i+57], x58=X[i+58], x59=X[i+59],
                              x60=X[i+60], x61=X[i+61], x62=X[i+62],
                              x63=X[i+63];

         prefX(X);
         A0[i+0] += y0 * x0;
         prefA(A0);
         A1[i+0] += y1 * x0;
         prefA(A1);
         A2[i+0] += y2 * x0;
         prefA(A2);
         A3[i+0] += y3 * x0;
         prefA(A3);
         A4[i+0] += y4 * x0;
         prefA(A4);
         A5[i+0] += y5 * x0;
         prefA(A5);
         A6[i+0] += y6 * x0;
         prefA(A6);
         A7[i+0] += y7 * x0;
         prefA(A7);
         A8[i+0] += y8 * x0;
         prefA(A8);
         A9[i+0] += y9 * x0;
         prefA(A9);
         A10[i+0] += y10 * x0;
         prefA(A10);
         A11[i+0] += y11 * x0;
         prefA(A11);
         A12[i+0] += y12 * x0;
         prefA(A12);
         A13[i+0] += y13 * x0;
         prefA(A13);
         A14[i+0] += y14 * x0;
         prefA(A14);
         A15[i+0] += y15 * x0;
         prefA(A15);
         A16[i+0] += y16 * x0;
         prefA(A16);
         A17[i+0] += y17 * x0;
         prefA(A17);
         A18[i+0] += y18 * x0;
         prefA(A18);
         A19[i+0] += y19 * x0;
         prefA(A19);
         A20[i+0] += y20 * x0;
         prefA(A20);
         A21[i+0] += y21 * x0;
         prefA(A21);
         A22[i+0] += y22 * x0;
         prefA(A22);
         A23[i+0] += y23 * x0;
         prefA(A23);
         A0[i+1] += y0 * x1;
         A1[i+1] += y1 * x1;
         A2[i+1] += y2 * x1;
         A3[i+1] += y3 * x1;
         A4[i+1] += y4 * x1;
         A5[i+1] += y5 * x1;
         A6[i+1] += y6 * x1;
         A7[i+1] += y7 * x1;
         A8[i+1] += y8 * x1;
         A9[i+1] += y9 * x1;
         A10[i+1] += y10 * x1;
         A11[i+1] += y11 * x1;
         A12[i+1] += y12 * x1;
         A13[i+1] += y13 * x1;
         A14[i+1] += y14 * x1;
         A15[i+1] += y15 * x1;
         A16[i+1] += y16 * x1;
         A17[i+1] += y17 * x1;
         A18[i+1] += y18 * x1;
         A19[i+1] += y19 * x1;
         A20[i+1] += y20 * x1;
         A21[i+1] += y21 * x1;
         A22[i+1] += y22 * x1;
         A23[i+1] += y23 * x1;
         A0[i+2] += y0 * x2;
         A1[i+2] += y1 * x2;
         A2[i+2] += y2 * x2;
         A3[i+2] += y3 * x2;
         A4[i+2] += y4 * x2;
         A5[i+2] += y5 * x2;
         A6[i+2] += y6 * x2;
         A7[i+2] += y7 * x2;
         A8[i+2] += y8 * x2;
         A9[i+2] += y9 * x2;
         A10[i+2] += y10 * x2;
         A11[i+2] += y11 * x2;
         A12[i+2] += y12 * x2;
         A13[i+2] += y13 * x2;
         A14[i+2] += y14 * x2;
         A15[i+2] += y15 * x2;
         A16[i+2] += y16 * x2;
         A17[i+2] += y17 * x2;
         A18[i+2] += y18 * x2;
         A19[i+2] += y19 * x2;
         A20[i+2] += y20 * x2;
         A21[i+2] += y21 * x2;
         A22[i+2] += y22 * x2;
         A23[i+2] += y23 * x2;
         A0[i+3] += y0 * x3;
         A1[i+3] += y1 * x3;
         A2[i+3] += y2 * x3;
         A3[i+3] += y3 * x3;
         A4[i+3] += y4 * x3;
         A5[i+3] += y5 * x3;
         A6[i+3] += y6 * x3;
         A7[i+3] += y7 * x3;
         A8[i+3] += y8 * x3;
         A9[i+3] += y9 * x3;
         A10[i+3] += y10 * x3;
         A11[i+3] += y11 * x3;
         A12[i+3] += y12 * x3;
         A13[i+3] += y13 * x3;
         A14[i+3] += y14 * x3;
         A15[i+3] += y15 * x3;
         A16[i+3] += y16 * x3;
         A17[i+3] += y17 * x3;
         A18[i+3] += y18 * x3;
         A19[i+3] += y19 * x3;
         A20[i+3] += y20 * x3;
         A21[i+3] += y21 * x3;
         A22[i+3] += y22 * x3;
         A23[i+3] += y23 * x3;
         A0[i+4] += y0 * x4;
         A1[i+4] += y1 * x4;
         A2[i+4] += y2 * x4;
         A3[i+4] += y3 * x4;
         A4[i+4] += y4 * x4;
         A5[i+4] += y5 * x4;
         A6[i+4] += y6 * x4;
         A7[i+4] += y7 * x4;
         A8[i+4] += y8 * x4;
         A9[i+4] += y9 * x4;
         A10[i+4] += y10 * x4;
         A11[i+4] += y11 * x4;
         A12[i+4] += y12 * x4;
         A13[i+4] += y13 * x4;
         A14[i+4] += y14 * x4;
         A15[i+4] += y15 * x4;
         A16[i+4] += y16 * x4;
         A17[i+4] += y17 * x4;
         A18[i+4] += y18 * x4;
         A19[i+4] += y19 * x4;
         A20[i+4] += y20 * x4;
         A21[i+4] += y21 * x4;
         A22[i+4] += y22 * x4;
         A23[i+4] += y23 * x4;
         A0[i+5] += y0 * x5;
         A1[i+5] += y1 * x5;
         A2[i+5] += y2 * x5;
         A3[i+5] += y3 * x5;
         A4[i+5] += y4 * x5;
         A5[i+5] += y5 * x5;
         A6[i+5] += y6 * x5;
         A7[i+5] += y7 * x5;
         A8[i+5] += y8 * x5;
         A9[i+5] += y9 * x5;
         A10[i+5] += y10 * x5;
         A11[i+5] += y11 * x5;
         A12[i+5] += y12 * x5;
         A13[i+5] += y13 * x5;
         A14[i+5] += y14 * x5;
         A15[i+5] += y15 * x5;
         A16[i+5] += y16 * x5;
         A17[i+5] += y17 * x5;
         A18[i+5] += y18 * x5;
         A19[i+5] += y19 * x5;
         A20[i+5] += y20 * x5;
         A21[i+5] += y21 * x5;
         A22[i+5] += y22 * x5;
         A23[i+5] += y23 * x5;
         A0[i+6] += y0 * x6;
         A1[i+6] += y1 * x6;
         A2[i+6] += y2 * x6;
         A3[i+6] += y3 * x6;
         A4[i+6] += y4 * x6;
         A5[i+6] += y5 * x6;
         A6[i+6] += y6 * x6;
         A7[i+6] += y7 * x6;
         A8[i+6] += y8 * x6;
         A9[i+6] += y9 * x6;
         A10[i+6] += y10 * x6;
         A11[i+6] += y11 * x6;
         A12[i+6] += y12 * x6;
         A13[i+6] += y13 * x6;
         A14[i+6] += y14 * x6;
         A15[i+6] += y15 * x6;
         A16[i+6] += y16 * x6;
         A17[i+6] += y17 * x6;
         A18[i+6] += y18 * x6;
         A19[i+6] += y19 * x6;
         A20[i+6] += y20 * x6;
         A21[i+6] += y21 * x6;
         A22[i+6] += y22 * x6;
         A23[i+6] += y23 * x6;
         A0[i+7] += y0 * x7;
         A1[i+7] += y1 * x7;
         A2[i+7] += y2 * x7;
         A3[i+7] += y3 * x7;
         A4[i+7] += y4 * x7;
         A5[i+7] += y5 * x7;
         A6[i+7] += y6 * x7;
         A7[i+7] += y7 * x7;
         A8[i+7] += y8 * x7;
         A9[i+7] += y9 * x7;
         A10[i+7] += y10 * x7;
         A11[i+7] += y11 * x7;
         A12[i+7] += y12 * x7;
         A13[i+7] += y13 * x7;
         A14[i+7] += y14 * x7;
         A15[i+7] += y15 * x7;
         A16[i+7] += y16 * x7;
         A17[i+7] += y17 * x7;
         A18[i+7] += y18 * x7;
         A19[i+7] += y19 * x7;
         A20[i+7] += y20 * x7;
         A21[i+7] += y21 * x7;
         A22[i+7] += y22 * x7;
         A23[i+7] += y23 * x7;
         A0[i+8] += y0 * x8;
         A1[i+8] += y1 * x8;
         A2[i+8] += y2 * x8;
         A3[i+8] += y3 * x8;
         A4[i+8] += y4 * x8;
         A5[i+8] += y5 * x8;
         A6[i+8] += y6 * x8;
         A7[i+8] += y7 * x8;
         A8[i+8] += y8 * x8;
         A9[i+8] += y9 * x8;
         A10[i+8] += y10 * x8;
         A11[i+8] += y11 * x8;
         A12[i+8] += y12 * x8;
         A13[i+8] += y13 * x8;
         A14[i+8] += y14 * x8;
         A15[i+8] += y15 * x8;
         A16[i+8] += y16 * x8;
         A17[i+8] += y17 * x8;
         A18[i+8] += y18 * x8;
         A19[i+8] += y19 * x8;
         A20[i+8] += y20 * x8;
         A21[i+8] += y21 * x8;
         A22[i+8] += y22 * x8;
         A23[i+8] += y23 * x8;
         A0[i+9] += y0 * x9;
         A1[i+9] += y1 * x9;
         A2[i+9] += y2 * x9;
         A3[i+9] += y3 * x9;
         A4[i+9] += y4 * x9;
         A5[i+9] += y5 * x9;
         A6[i+9] += y6 * x9;
         A7[i+9] += y7 * x9;
         A8[i+9] += y8 * x9;
         A9[i+9] += y9 * x9;
         A10[i+9] += y10 * x9;
         A11[i+9] += y11 * x9;
         A12[i+9] += y12 * x9;
         A13[i+9] += y13 * x9;
         A14[i+9] += y14 * x9;
         A15[i+9] += y15 * x9;
         A16[i+9] += y16 * x9;
         A17[i+9] += y17 * x9;
         A18[i+9] += y18 * x9;
         A19[i+9] += y19 * x9;
         A20[i+9] += y20 * x9;
         A21[i+9] += y21 * x9;
         A22[i+9] += y22 * x9;
         A23[i+9] += y23 * x9;
         A0[i+10] += y0 * x10;
         A1[i+10] += y1 * x10;
         A2[i+10] += y2 * x10;
         A3[i+10] += y3 * x10;
         A4[i+10] += y4 * x10;
         A5[i+10] += y5 * x10;
         A6[i+10] += y6 * x10;
         A7[i+10] += y7 * x10;
         A8[i+10] += y8 * x10;
         A9[i+10] += y9 * x10;
         A10[i+10] += y10 * x10;
         A11[i+10] += y11 * x10;
         A12[i+10] += y12 * x10;
         A13[i+10] += y13 * x10;
         A14[i+10] += y14 * x10;
         A15[i+10] += y15 * x10;
         A16[i+10] += y16 * x10;
         A17[i+10] += y17 * x10;
         A18[i+10] += y18 * x10;
         A19[i+10] += y19 * x10;
         A20[i+10] += y20 * x10;
         A21[i+10] += y21 * x10;
         A22[i+10] += y22 * x10;
         A23[i+10] += y23 * x10;
         A0[i+11] += y0 * x11;
         A1[i+11] += y1 * x11;
         A2[i+11] += y2 * x11;
         A3[i+11] += y3 * x11;
         A4[i+11] += y4 * x11;
         A5[i+11] += y5 * x11;
         A6[i+11] += y6 * x11;
         A7[i+11] += y7 * x11;
         A8[i+11] += y8 * x11;
         A9[i+11] += y9 * x11;
         A10[i+11] += y10 * x11;
         A11[i+11] += y11 * x11;
         A12[i+11] += y12 * x11;
         A13[i+11] += y13 * x11;
         A14[i+11] += y14 * x11;
         A15[i+11] += y15 * x11;
         A16[i+11] += y16 * x11;
         A17[i+11] += y17 * x11;
         A18[i+11] += y18 * x11;
         A19[i+11] += y19 * x11;
         A20[i+11] += y20 * x11;
         A21[i+11] += y21 * x11;
         A22[i+11] += y22 * x11;
         A23[i+11] += y23 * x11;
         A0[i+12] += y0 * x12;
         A1[i+12] += y1 * x12;
         A2[i+12] += y2 * x12;
         A3[i+12] += y3 * x12;
         A4[i+12] += y4 * x12;
         A5[i+12] += y5 * x12;
         A6[i+12] += y6 * x12;
         A7[i+12] += y7 * x12;
         A8[i+12] += y8 * x12;
         A9[i+12] += y9 * x12;
         A10[i+12] += y10 * x12;
         A11[i+12] += y11 * x12;
         A12[i+12] += y12 * x12;
         A13[i+12] += y13 * x12;
         A14[i+12] += y14 * x12;
         A15[i+12] += y15 * x12;
         A16[i+12] += y16 * x12;
         A17[i+12] += y17 * x12;
         A18[i+12] += y18 * x12;
         A19[i+12] += y19 * x12;
         A20[i+12] += y20 * x12;
         A21[i+12] += y21 * x12;
         A22[i+12] += y22 * x12;
         A23[i+12] += y23 * x12;
         A0[i+13] += y0 * x13;
         A1[i+13] += y1 * x13;
         A2[i+13] += y2 * x13;
         A3[i+13] += y3 * x13;
         A4[i+13] += y4 * x13;
         A5[i+13] += y5 * x13;
         A6[i+13] += y6 * x13;
         A7[i+13] += y7 * x13;
         A8[i+13] += y8 * x13;
         A9[i+13] += y9 * x13;
         A10[i+13] += y10 * x13;
         A11[i+13] += y11 * x13;
         A12[i+13] += y12 * x13;
         A13[i+13] += y13 * x13;
         A14[i+13] += y14 * x13;
         A15[i+13] += y15 * x13;
         A16[i+13] += y16 * x13;
         A17[i+13] += y17 * x13;
         A18[i+13] += y18 * x13;
         A19[i+13] += y19 * x13;
         A20[i+13] += y20 * x13;
         A21[i+13] += y21 * x13;
         A22[i+13] += y22 * x13;
         A23[i+13] += y23 * x13;
         A0[i+14] += y0 * x14;
         A1[i+14] += y1 * x14;
         A2[i+14] += y2 * x14;
         A3[i+14] += y3 * x14;
         A4[i+14] += y4 * x14;
         A5[i+14] += y5 * x14;
         A6[i+14] += y6 * x14;
         A7[i+14] += y7 * x14;
         A8[i+14] += y8 * x14;
         A9[i+14] += y9 * x14;
         A10[i+14] += y10 * x14;
         A11[i+14] += y11 * x14;
         A12[i+14] += y12 * x14;
         A13[i+14] += y13 * x14;
         A14[i+14] += y14 * x14;
         A15[i+14] += y15 * x14;
         A16[i+14] += y16 * x14;
         A17[i+14] += y17 * x14;
         A18[i+14] += y18 * x14;
         A19[i+14] += y19 * x14;
         A20[i+14] += y20 * x14;
         A21[i+14] += y21 * x14;
         A22[i+14] += y22 * x14;
         A23[i+14] += y23 * x14;
         A0[i+15] += y0 * x15;
         A1[i+15] += y1 * x15;
         A2[i+15] += y2 * x15;
         A3[i+15] += y3 * x15;
         A4[i+15] += y4 * x15;
         A5[i+15] += y5 * x15;
         A6[i+15] += y6 * x15;
         A7[i+15] += y7 * x15;
         A8[i+15] += y8 * x15;
         A9[i+15] += y9 * x15;
         A10[i+15] += y10 * x15;
         A11[i+15] += y11 * x15;
         A12[i+15] += y12 * x15;
         A13[i+15] += y13 * x15;
         A14[i+15] += y14 * x15;
         A15[i+15] += y15 * x15;
         A16[i+15] += y16 * x15;
         A17[i+15] += y17 * x15;
         A18[i+15] += y18 * x15;
         A19[i+15] += y19 * x15;
         A20[i+15] += y20 * x15;
         A21[i+15] += y21 * x15;
         A22[i+15] += y22 * x15;
         A23[i+15] += y23 * x15;
         A0[i+16] += y0 * x16;
         prefA(A0);
         A1[i+16] += y1 * x16;
         prefA(A1);
         A2[i+16] += y2 * x16;
         prefA(A2);
         A3[i+16] += y3 * x16;
         prefA(A3);
         A4[i+16] += y4 * x16;
         prefA(A4);
         A5[i+16] += y5 * x16;
         prefA(A5);
         A6[i+16] += y6 * x16;
         prefA(A6);
         A7[i+16] += y7 * x16;
         prefA(A7);
         A8[i+16] += y8 * x16;
         prefA(A8);
         A9[i+16] += y9 * x16;
         prefA(A9);
         A10[i+16] += y10 * x16;
         prefA(A10);
         A11[i+16] += y11 * x16;
         prefA(A11);
         A12[i+16] += y12 * x16;
         prefA(A12);
         A13[i+16] += y13 * x16;
         prefA(A13);
         A14[i+16] += y14 * x16;
         prefA(A14);
         A15[i+16] += y15 * x16;
         prefA(A15);
         A16[i+16] += y16 * x16;
         prefA(A16);
         A17[i+16] += y17 * x16;
         prefA(A17);
         A18[i+16] += y18 * x16;
         prefA(A18);
         A19[i+16] += y19 * x16;
         prefA(A19);
         A20[i+16] += y20 * x16;
         prefA(A20);
         A21[i+16] += y21 * x16;
         prefA(A21);
         A22[i+16] += y22 * x16;
         prefA(A22);
         A23[i+16] += y23 * x16;
         prefA(A23);
         A0[i+17] += y0 * x17;
         A1[i+17] += y1 * x17;
         A2[i+17] += y2 * x17;
         A3[i+17] += y3 * x17;
         A4[i+17] += y4 * x17;
         A5[i+17] += y5 * x17;
         A6[i+17] += y6 * x17;
         A7[i+17] += y7 * x17;
         A8[i+17] += y8 * x17;
         A9[i+17] += y9 * x17;
         A10[i+17] += y10 * x17;
         A11[i+17] += y11 * x17;
         A12[i+17] += y12 * x17;
         A13[i+17] += y13 * x17;
         A14[i+17] += y14 * x17;
         A15[i+17] += y15 * x17;
         A16[i+17] += y16 * x17;
         A17[i+17] += y17 * x17;
         A18[i+17] += y18 * x17;
         A19[i+17] += y19 * x17;
         A20[i+17] += y20 * x17;
         A21[i+17] += y21 * x17;
         A22[i+17] += y22 * x17;
         A23[i+17] += y23 * x17;
         A0[i+18] += y0 * x18;
         A1[i+18] += y1 * x18;
         A2[i+18] += y2 * x18;
         A3[i+18] += y3 * x18;
         A4[i+18] += y4 * x18;
         A5[i+18] += y5 * x18;
         A6[i+18] += y6 * x18;
         A7[i+18] += y7 * x18;
         A8[i+18] += y8 * x18;
         A9[i+18] += y9 * x18;
         A10[i+18] += y10 * x18;
         A11[i+18] += y11 * x18;
         A12[i+18] += y12 * x18;
         A13[i+18] += y13 * x18;
         A14[i+18] += y14 * x18;
         A15[i+18] += y15 * x18;
         A16[i+18] += y16 * x18;
         A17[i+18] += y17 * x18;
         A18[i+18] += y18 * x18;
         A19[i+18] += y19 * x18;
         A20[i+18] += y20 * x18;
         A21[i+18] += y21 * x18;
         A22[i+18] += y22 * x18;
         A23[i+18] += y23 * x18;
         A0[i+19] += y0 * x19;
         A1[i+19] += y1 * x19;
         A2[i+19] += y2 * x19;
         A3[i+19] += y3 * x19;
         A4[i+19] += y4 * x19;
         A5[i+19] += y5 * x19;
         A6[i+19] += y6 * x19;
         A7[i+19] += y7 * x19;
         A8[i+19] += y8 * x19;
         A9[i+19] += y9 * x19;
         A10[i+19] += y10 * x19;
         A11[i+19] += y11 * x19;
         A12[i+19] += y12 * x19;
         A13[i+19] += y13 * x19;
         A14[i+19] += y14 * x19;
         A15[i+19] += y15 * x19;
         A16[i+19] += y16 * x19;
         A17[i+19] += y17 * x19;
         A18[i+19] += y18 * x19;
         A19[i+19] += y19 * x19;
         A20[i+19] += y20 * x19;
         A21[i+19] += y21 * x19;
         A22[i+19] += y22 * x19;
         A23[i+19] += y23 * x19;
         A0[i+20] += y0 * x20;
         A1[i+20] += y1 * x20;
         A2[i+20] += y2 * x20;
         A3[i+20] += y3 * x20;
         A4[i+20] += y4 * x20;
         A5[i+20] += y5 * x20;
         A6[i+20] += y6 * x20;
         A7[i+20] += y7 * x20;
         A8[i+20] += y8 * x20;
         A9[i+20] += y9 * x20;
         A10[i+20] += y10 * x20;
         A11[i+20] += y11 * x20;
         A12[i+20] += y12 * x20;
         A13[i+20] += y13 * x20;
         A14[i+20] += y14 * x20;
         A15[i+20] += y15 * x20;
         A16[i+20] += y16 * x20;
         A17[i+20] += y17 * x20;
         A18[i+20] += y18 * x20;
         A19[i+20] += y19 * x20;
         A20[i+20] += y20 * x20;
         A21[i+20] += y21 * x20;
         A22[i+20] += y22 * x20;
         A23[i+20] += y23 * x20;
         A0[i+21] += y0 * x21;
         A1[i+21] += y1 * x21;
         A2[i+21] += y2 * x21;
         A3[i+21] += y3 * x21;
         A4[i+21] += y4 * x21;
         A5[i+21] += y5 * x21;
         A6[i+21] += y6 * x21;
         A7[i+21] += y7 * x21;
         A8[i+21] += y8 * x21;
         A9[i+21] += y9 * x21;
         A10[i+21] += y10 * x21;
         A11[i+21] += y11 * x21;
         A12[i+21] += y12 * x21;
         A13[i+21] += y13 * x21;
         A14[i+21] += y14 * x21;
         A15[i+21] += y15 * x21;
         A16[i+21] += y16 * x21;
         A17[i+21] += y17 * x21;
         A18[i+21] += y18 * x21;
         A19[i+21] += y19 * x21;
         A20[i+21] += y20 * x21;
         A21[i+21] += y21 * x21;
         A22[i+21] += y22 * x21;
         A23[i+21] += y23 * x21;
         A0[i+22] += y0 * x22;
         A1[i+22] += y1 * x22;
         A2[i+22] += y2 * x22;
         A3[i+22] += y3 * x22;
         A4[i+22] += y4 * x22;
         A5[i+22] += y5 * x22;
         A6[i+22] += y6 * x22;
         A7[i+22] += y7 * x22;
         A8[i+22] += y8 * x22;
         A9[i+22] += y9 * x22;
         A10[i+22] += y10 * x22;
         A11[i+22] += y11 * x22;
         A12[i+22] += y12 * x22;
         A13[i+22] += y13 * x22;
         A14[i+22] += y14 * x22;
         A15[i+22] += y15 * x22;
         A16[i+22] += y16 * x22;
         A17[i+22] += y17 * x22;
         A18[i+22] += y18 * x22;
         A19[i+22] += y19 * x22;
         A20[i+22] += y20 * x22;
         A21[i+22] += y21 * x22;
         A22[i+22] += y22 * x22;
         A23[i+22] += y23 * x22;
         A0[i+23] += y0 * x23;
         A1[i+23] += y1 * x23;
         A2[i+23] += y2 * x23;
         A3[i+23] += y3 * x23;
         A4[i+23] += y4 * x23;
         A5[i+23] += y5 * x23;
         A6[i+23] += y6 * x23;
         A7[i+23] += y7 * x23;
         A8[i+23] += y8 * x23;
         A9[i+23] += y9 * x23;
         A10[i+23] += y10 * x23;
         A11[i+23] += y11 * x23;
         A12[i+23] += y12 * x23;
         A13[i+23] += y13 * x23;
         A14[i+23] += y14 * x23;
         A15[i+23] += y15 * x23;
         A16[i+23] += y16 * x23;
         A17[i+23] += y17 * x23;
         A18[i+23] += y18 * x23;
         A19[i+23] += y19 * x23;
         A20[i+23] += y20 * x23;
         A21[i+23] += y21 * x23;
         A22[i+23] += y22 * x23;
         A23[i+23] += y23 * x23;
         A0[i+24] += y0 * x24;
         A1[i+24] += y1 * x24;
         A2[i+24] += y2 * x24;
         A3[i+24] += y3 * x24;
         A4[i+24] += y4 * x24;
         A5[i+24] += y5 * x24;
         A6[i+24] += y6 * x24;
         A7[i+24] += y7 * x24;
         A8[i+24] += y8 * x24;
         A9[i+24] += y9 * x24;
         A10[i+24] += y10 * x24;
         A11[i+24] += y11 * x24;
         A12[i+24] += y12 * x24;
         A13[i+24] += y13 * x24;
         A14[i+24] += y14 * x24;
         A15[i+24] += y15 * x24;
         A16[i+24] += y16 * x24;
         A17[i+24] += y17 * x24;
         A18[i+24] += y18 * x24;
         A19[i+24] += y19 * x24;
         A20[i+24] += y20 * x24;
         A21[i+24] += y21 * x24;
         A22[i+24] += y22 * x24;
         A23[i+24] += y23 * x24;
         A0[i+25] += y0 * x25;
         A1[i+25] += y1 * x25;
         A2[i+25] += y2 * x25;
         A3[i+25] += y3 * x25;
         A4[i+25] += y4 * x25;
         A5[i+25] += y5 * x25;
         A6[i+25] += y6 * x25;
         A7[i+25] += y7 * x25;
         A8[i+25] += y8 * x25;
         A9[i+25] += y9 * x25;
         A10[i+25] += y10 * x25;
         A11[i+25] += y11 * x25;
         A12[i+25] += y12 * x25;
         A13[i+25] += y13 * x25;
         A14[i+25] += y14 * x25;
         A15[i+25] += y15 * x25;
         A16[i+25] += y16 * x25;
         A17[i+25] += y17 * x25;
         A18[i+25] += y18 * x25;
         A19[i+25] += y19 * x25;
         A20[i+25] += y20 * x25;
         A21[i+25] += y21 * x25;
         A22[i+25] += y22 * x25;
         A23[i+25] += y23 * x25;
         A0[i+26] += y0 * x26;
         A1[i+26] += y1 * x26;
         A2[i+26] += y2 * x26;
         A3[i+26] += y3 * x26;
         A4[i+26] += y4 * x26;
         A5[i+26] += y5 * x26;
         A6[i+26] += y6 * x26;
         A7[i+26] += y7 * x26;
         A8[i+26] += y8 * x26;
         A9[i+26] += y9 * x26;
         A10[i+26] += y10 * x26;
         A11[i+26] += y11 * x26;
         A12[i+26] += y12 * x26;
         A13[i+26] += y13 * x26;
         A14[i+26] += y14 * x26;
         A15[i+26] += y15 * x26;
         A16[i+26] += y16 * x26;
         A17[i+26] += y17 * x26;
         A18[i+26] += y18 * x26;
         A19[i+26] += y19 * x26;
         A20[i+26] += y20 * x26;
         A21[i+26] += y21 * x26;
         A22[i+26] += y22 * x26;
         A23[i+26] += y23 * x26;
         A0[i+27] += y0 * x27;
         A1[i+27] += y1 * x27;
         A2[i+27] += y2 * x27;
         A3[i+27] += y3 * x27;
         A4[i+27] += y4 * x27;
         A5[i+27] += y5 * x27;
         A6[i+27] += y6 * x27;
         A7[i+27] += y7 * x27;
         A8[i+27] += y8 * x27;
         A9[i+27] += y9 * x27;
         A10[i+27] += y10 * x27;
         A11[i+27] += y11 * x27;
         A12[i+27] += y12 * x27;
         A13[i+27] += y13 * x27;
         A14[i+27] += y14 * x27;
         A15[i+27] += y15 * x27;
         A16[i+27] += y16 * x27;
         A17[i+27] += y17 * x27;
         A18[i+27] += y18 * x27;
         A19[i+27] += y19 * x27;
         A20[i+27] += y20 * x27;
         A21[i+27] += y21 * x27;
         A22[i+27] += y22 * x27;
         A23[i+27] += y23 * x27;
         A0[i+28] += y0 * x28;
         A1[i+28] += y1 * x28;
         A2[i+28] += y2 * x28;
         A3[i+28] += y3 * x28;
         A4[i+28] += y4 * x28;
         A5[i+28] += y5 * x28;
         A6[i+28] += y6 * x28;
         A7[i+28] += y7 * x28;
         A8[i+28] += y8 * x28;
         A9[i+28] += y9 * x28;
         A10[i+28] += y10 * x28;
         A11[i+28] += y11 * x28;
         A12[i+28] += y12 * x28;
         A13[i+28] += y13 * x28;
         A14[i+28] += y14 * x28;
         A15[i+28] += y15 * x28;
         A16[i+28] += y16 * x28;
         A17[i+28] += y17 * x28;
         A18[i+28] += y18 * x28;
         A19[i+28] += y19 * x28;
         A20[i+28] += y20 * x28;
         A21[i+28] += y21 * x28;
         A22[i+28] += y22 * x28;
         A23[i+28] += y23 * x28;
         A0[i+29] += y0 * x29;
         A1[i+29] += y1 * x29;
         A2[i+29] += y2 * x29;
         A3[i+29] += y3 * x29;
         A4[i+29] += y4 * x29;
         A5[i+29] += y5 * x29;
         A6[i+29] += y6 * x29;
         A7[i+29] += y7 * x29;
         A8[i+29] += y8 * x29;
         A9[i+29] += y9 * x29;
         A10[i+29] += y10 * x29;
         A11[i+29] += y11 * x29;
         A12[i+29] += y12 * x29;
         A13[i+29] += y13 * x29;
         A14[i+29] += y14 * x29;
         A15[i+29] += y15 * x29;
         A16[i+29] += y16 * x29;
         A17[i+29] += y17 * x29;
         A18[i+29] += y18 * x29;
         A19[i+29] += y19 * x29;
         A20[i+29] += y20 * x29;
         A21[i+29] += y21 * x29;
         A22[i+29] += y22 * x29;
         A23[i+29] += y23 * x29;
         A0[i+30] += y0 * x30;
         A1[i+30] += y1 * x30;
         A2[i+30] += y2 * x30;
         A3[i+30] += y3 * x30;
         A4[i+30] += y4 * x30;
         A5[i+30] += y5 * x30;
         A6[i+30] += y6 * x30;
         A7[i+30] += y7 * x30;
         A8[i+30] += y8 * x30;
         A9[i+30] += y9 * x30;
         A10[i+30] += y10 * x30;
         A11[i+30] += y11 * x30;
         A12[i+30] += y12 * x30;
         A13[i+30] += y13 * x30;
         A14[i+30] += y14 * x30;
         A15[i+30] += y15 * x30;
         A16[i+30] += y16 * x30;
         A17[i+30] += y17 * x30;
         A18[i+30] += y18 * x30;
         A19[i+30] += y19 * x30;
         A20[i+30] += y20 * x30;
         A21[i+30] += y21 * x30;
         A22[i+30] += y22 * x30;
         A23[i+30] += y23 * x30;
         A0[i+31] += y0 * x31;
         A1[i+31] += y1 * x31;
         A2[i+31] += y2 * x31;
         A3[i+31] += y3 * x31;
         A4[i+31] += y4 * x31;
         A5[i+31] += y5 * x31;
         A6[i+31] += y6 * x31;
         A7[i+31] += y7 * x31;
         A8[i+31] += y8 * x31;
         A9[i+31] += y9 * x31;
         A10[i+31] += y10 * x31;
         A11[i+31] += y11 * x31;
         A12[i+31] += y12 * x31;
         A13[i+31] += y13 * x31;
         A14[i+31] += y14 * x31;
         A15[i+31] += y15 * x31;
         A16[i+31] += y16 * x31;
         A17[i+31] += y17 * x31;
         A18[i+31] += y18 * x31;
         A19[i+31] += y19 * x31;
         A20[i+31] += y20 * x31;
         A21[i+31] += y21 * x31;
         A22[i+31] += y22 * x31;
         A23[i+31] += y23 * x31;
         A0[i+32] += y0 * x32;
         prefA(A0);
         A1[i+32] += y1 * x32;
         prefA(A1);
         A2[i+32] += y2 * x32;
         prefA(A2);
         A3[i+32] += y3 * x32;
         prefA(A3);
         A4[i+32] += y4 * x32;
         prefA(A4);
         A5[i+32] += y5 * x32;
         prefA(A5);
         A6[i+32] += y6 * x32;
         prefA(A6);
         A7[i+32] += y7 * x32;
         prefA(A7);
         A8[i+32] += y8 * x32;
         prefA(A8);
         A9[i+32] += y9 * x32;
         prefA(A9);
         A10[i+32] += y10 * x32;
         prefA(A10);
         A11[i+32] += y11 * x32;
         prefA(A11);
         A12[i+32] += y12 * x32;
         prefA(A12);
         A13[i+32] += y13 * x32;
         prefA(A13);
         A14[i+32] += y14 * x32;
         prefA(A14);
         A15[i+32] += y15 * x32;
         prefA(A15);
         A16[i+32] += y16 * x32;
         prefA(A16);
         A17[i+32] += y17 * x32;
         prefA(A17);
         A18[i+32] += y18 * x32;
         prefA(A18);
         A19[i+32] += y19 * x32;
         prefA(A19);
         A20[i+32] += y20 * x32;
         prefA(A20);
         A21[i+32] += y21 * x32;
         prefA(A21);
         A22[i+32] += y22 * x32;
         prefA(A22);
         A23[i+32] += y23 * x32;
         prefA(A23);
         A0[i+33] += y0 * x33;
         A1[i+33] += y1 * x33;
         A2[i+33] += y2 * x33;
         A3[i+33] += y3 * x33;
         A4[i+33] += y4 * x33;
         A5[i+33] += y5 * x33;
         A6[i+33] += y6 * x33;
         A7[i+33] += y7 * x33;
         A8[i+33] += y8 * x33;
         A9[i+33] += y9 * x33;
         A10[i+33] += y10 * x33;
         A11[i+33] += y11 * x33;
         A12[i+33] += y12 * x33;
         A13[i+33] += y13 * x33;
         A14[i+33] += y14 * x33;
         A15[i+33] += y15 * x33;
         A16[i+33] += y16 * x33;
         A17[i+33] += y17 * x33;
         A18[i+33] += y18 * x33;
         A19[i+33] += y19 * x33;
         A20[i+33] += y20 * x33;
         A21[i+33] += y21 * x33;
         A22[i+33] += y22 * x33;
         A23[i+33] += y23 * x33;
         A0[i+34] += y0 * x34;
         A1[i+34] += y1 * x34;
         A2[i+34] += y2 * x34;
         A3[i+34] += y3 * x34;
         A4[i+34] += y4 * x34;
         A5[i+34] += y5 * x34;
         A6[i+34] += y6 * x34;
         A7[i+34] += y7 * x34;
         A8[i+34] += y8 * x34;
         A9[i+34] += y9 * x34;
         A10[i+34] += y10 * x34;
         A11[i+34] += y11 * x34;
         A12[i+34] += y12 * x34;
         A13[i+34] += y13 * x34;
         A14[i+34] += y14 * x34;
         A15[i+34] += y15 * x34;
         A16[i+34] += y16 * x34;
         A17[i+34] += y17 * x34;
         A18[i+34] += y18 * x34;
         A19[i+34] += y19 * x34;
         A20[i+34] += y20 * x34;
         A21[i+34] += y21 * x34;
         A22[i+34] += y22 * x34;
         A23[i+34] += y23 * x34;
         A0[i+35] += y0 * x35;
         A1[i+35] += y1 * x35;
         A2[i+35] += y2 * x35;
         A3[i+35] += y3 * x35;
         A4[i+35] += y4 * x35;
         A5[i+35] += y5 * x35;
         A6[i+35] += y6 * x35;
         A7[i+35] += y7 * x35;
         A8[i+35] += y8 * x35;
         A9[i+35] += y9 * x35;
         A10[i+35] += y10 * x35;
         A11[i+35] += y11 * x35;
         A12[i+35] += y12 * x35;
         A13[i+35] += y13 * x35;
         A14[i+35] += y14 * x35;
         A15[i+35] += y15 * x35;
         A16[i+35] += y16 * x35;
         A17[i+35] += y17 * x35;
         A18[i+35] += y18 * x35;
         A19[i+35] += y19 * x35;
         A20[i+35] += y20 * x35;
         A21[i+35] += y21 * x35;
         A22[i+35] += y22 * x35;
         A23[i+35] += y23 * x35;
         A0[i+36] += y0 * x36;
         A1[i+36] += y1 * x36;
         A2[i+36] += y2 * x36;
         A3[i+36] += y3 * x36;
         A4[i+36] += y4 * x36;
         A5[i+36] += y5 * x36;
         A6[i+36] += y6 * x36;
         A7[i+36] += y7 * x36;
         A8[i+36] += y8 * x36;
         A9[i+36] += y9 * x36;
         A10[i+36] += y10 * x36;
         A11[i+36] += y11 * x36;
         A12[i+36] += y12 * x36;
         A13[i+36] += y13 * x36;
         A14[i+36] += y14 * x36;
         A15[i+36] += y15 * x36;
         A16[i+36] += y16 * x36;
         A17[i+36] += y17 * x36;
         A18[i+36] += y18 * x36;
         A19[i+36] += y19 * x36;
         A20[i+36] += y20 * x36;
         A21[i+36] += y21 * x36;
         A22[i+36] += y22 * x36;
         A23[i+36] += y23 * x36;
         A0[i+37] += y0 * x37;
         A1[i+37] += y1 * x37;
         A2[i+37] += y2 * x37;
         A3[i+37] += y3 * x37;
         A4[i+37] += y4 * x37;
         A5[i+37] += y5 * x37;
         A6[i+37] += y6 * x37;
         A7[i+37] += y7 * x37;
         A8[i+37] += y8 * x37;
         A9[i+37] += y9 * x37;
         A10[i+37] += y10 * x37;
         A11[i+37] += y11 * x37;
         A12[i+37] += y12 * x37;
         A13[i+37] += y13 * x37;
         A14[i+37] += y14 * x37;
         A15[i+37] += y15 * x37;
         A16[i+37] += y16 * x37;
         A17[i+37] += y17 * x37;
         A18[i+37] += y18 * x37;
         A19[i+37] += y19 * x37;
         A20[i+37] += y20 * x37;
         A21[i+37] += y21 * x37;
         A22[i+37] += y22 * x37;
         A23[i+37] += y23 * x37;
         A0[i+38] += y0 * x38;
         A1[i+38] += y1 * x38;
         A2[i+38] += y2 * x38;
         A3[i+38] += y3 * x38;
         A4[i+38] += y4 * x38;
         A5[i+38] += y5 * x38;
         A6[i+38] += y6 * x38;
         A7[i+38] += y7 * x38;
         A8[i+38] += y8 * x38;
         A9[i+38] += y9 * x38;
         A10[i+38] += y10 * x38;
         A11[i+38] += y11 * x38;
         A12[i+38] += y12 * x38;
         A13[i+38] += y13 * x38;
         A14[i+38] += y14 * x38;
         A15[i+38] += y15 * x38;
         A16[i+38] += y16 * x38;
         A17[i+38] += y17 * x38;
         A18[i+38] += y18 * x38;
         A19[i+38] += y19 * x38;
         A20[i+38] += y20 * x38;
         A21[i+38] += y21 * x38;
         A22[i+38] += y22 * x38;
         A23[i+38] += y23 * x38;
         A0[i+39] += y0 * x39;
         A1[i+39] += y1 * x39;
         A2[i+39] += y2 * x39;
         A3[i+39] += y3 * x39;
         A4[i+39] += y4 * x39;
         A5[i+39] += y5 * x39;
         A6[i+39] += y6 * x39;
         A7[i+39] += y7 * x39;
         A8[i+39] += y8 * x39;
         A9[i+39] += y9 * x39;
         A10[i+39] += y10 * x39;
         A11[i+39] += y11 * x39;
         A12[i+39] += y12 * x39;
         A13[i+39] += y13 * x39;
         A14[i+39] += y14 * x39;
         A15[i+39] += y15 * x39;
         A16[i+39] += y16 * x39;
         A17[i+39] += y17 * x39;
         A18[i+39] += y18 * x39;
         A19[i+39] += y19 * x39;
         A20[i+39] += y20 * x39;
         A21[i+39] += y21 * x39;
         A22[i+39] += y22 * x39;
         A23[i+39] += y23 * x39;
         A0[i+40] += y0 * x40;
         A1[i+40] += y1 * x40;
         A2[i+40] += y2 * x40;
         A3[i+40] += y3 * x40;
         A4[i+40] += y4 * x40;
         A5[i+40] += y5 * x40;
         A6[i+40] += y6 * x40;
         A7[i+40] += y7 * x40;
         A8[i+40] += y8 * x40;
         A9[i+40] += y9 * x40;
         A10[i+40] += y10 * x40;
         A11[i+40] += y11 * x40;
         A12[i+40] += y12 * x40;
         A13[i+40] += y13 * x40;
         A14[i+40] += y14 * x40;
         A15[i+40] += y15 * x40;
         A16[i+40] += y16 * x40;
         A17[i+40] += y17 * x40;
         A18[i+40] += y18 * x40;
         A19[i+40] += y19 * x40;
         A20[i+40] += y20 * x40;
         A21[i+40] += y21 * x40;
         A22[i+40] += y22 * x40;
         A23[i+40] += y23 * x40;
         A0[i+41] += y0 * x41;
         A1[i+41] += y1 * x41;
         A2[i+41] += y2 * x41;
         A3[i+41] += y3 * x41;
         A4[i+41] += y4 * x41;
         A5[i+41] += y5 * x41;
         A6[i+41] += y6 * x41;
         A7[i+41] += y7 * x41;
         A8[i+41] += y8 * x41;
         A9[i+41] += y9 * x41;
         A10[i+41] += y10 * x41;
         A11[i+41] += y11 * x41;
         A12[i+41] += y12 * x41;
         A13[i+41] += y13 * x41;
         A14[i+41] += y14 * x41;
         A15[i+41] += y15 * x41;
         A16[i+41] += y16 * x41;
         A17[i+41] += y17 * x41;
         A18[i+41] += y18 * x41;
         A19[i+41] += y19 * x41;
         A20[i+41] += y20 * x41;
         A21[i+41] += y21 * x41;
         A22[i+41] += y22 * x41;
         A23[i+41] += y23 * x41;
         A0[i+42] += y0 * x42;
         A1[i+42] += y1 * x42;
         A2[i+42] += y2 * x42;
         A3[i+42] += y3 * x42;
         A4[i+42] += y4 * x42;
         A5[i+42] += y5 * x42;
         A6[i+42] += y6 * x42;
         A7[i+42] += y7 * x42;
         A8[i+42] += y8 * x42;
         A9[i+42] += y9 * x42;
         A10[i+42] += y10 * x42;
         A11[i+42] += y11 * x42;
         A12[i+42] += y12 * x42;
         A13[i+42] += y13 * x42;
         A14[i+42] += y14 * x42;
         A15[i+42] += y15 * x42;
         A16[i+42] += y16 * x42;
         A17[i+42] += y17 * x42;
         A18[i+42] += y18 * x42;
         A19[i+42] += y19 * x42;
         A20[i+42] += y20 * x42;
         A21[i+42] += y21 * x42;
         A22[i+42] += y22 * x42;
         A23[i+42] += y23 * x42;
         A0[i+43] += y0 * x43;
         A1[i+43] += y1 * x43;
         A2[i+43] += y2 * x43;
         A3[i+43] += y3 * x43;
         A4[i+43] += y4 * x43;
         A5[i+43] += y5 * x43;
         A6[i+43] += y6 * x43;
         A7[i+43] += y7 * x43;
         A8[i+43] += y8 * x43;
         A9[i+43] += y9 * x43;
         A10[i+43] += y10 * x43;
         A11[i+43] += y11 * x43;
         A12[i+43] += y12 * x43;
         A13[i+43] += y13 * x43;
         A14[i+43] += y14 * x43;
         A15[i+43] += y15 * x43;
         A16[i+43] += y16 * x43;
         A17[i+43] += y17 * x43;
         A18[i+43] += y18 * x43;
         A19[i+43] += y19 * x43;
         A20[i+43] += y20 * x43;
         A21[i+43] += y21 * x43;
         A22[i+43] += y22 * x43;
         A23[i+43] += y23 * x43;
         A0[i+44] += y0 * x44;
         A1[i+44] += y1 * x44;
         A2[i+44] += y2 * x44;
         A3[i+44] += y3 * x44;
         A4[i+44] += y4 * x44;
         A5[i+44] += y5 * x44;
         A6[i+44] += y6 * x44;
         A7[i+44] += y7 * x44;
         A8[i+44] += y8 * x44;
         A9[i+44] += y9 * x44;
         A10[i+44] += y10 * x44;
         A11[i+44] += y11 * x44;
         A12[i+44] += y12 * x44;
         A13[i+44] += y13 * x44;
         A14[i+44] += y14 * x44;
         A15[i+44] += y15 * x44;
         A16[i+44] += y16 * x44;
         A17[i+44] += y17 * x44;
         A18[i+44] += y18 * x44;
         A19[i+44] += y19 * x44;
         A20[i+44] += y20 * x44;
         A21[i+44] += y21 * x44;
         A22[i+44] += y22 * x44;
         A23[i+44] += y23 * x44;
         A0[i+45] += y0 * x45;
         A1[i+45] += y1 * x45;
         A2[i+45] += y2 * x45;
         A3[i+45] += y3 * x45;
         A4[i+45] += y4 * x45;
         A5[i+45] += y5 * x45;
         A6[i+45] += y6 * x45;
         A7[i+45] += y7 * x45;
         A8[i+45] += y8 * x45;
         A9[i+45] += y9 * x45;
         A10[i+45] += y10 * x45;
         A11[i+45] += y11 * x45;
         A12[i+45] += y12 * x45;
         A13[i+45] += y13 * x45;
         A14[i+45] += y14 * x45;
         A15[i+45] += y15 * x45;
         A16[i+45] += y16 * x45;
         A17[i+45] += y17 * x45;
         A18[i+45] += y18 * x45;
         A19[i+45] += y19 * x45;
         A20[i+45] += y20 * x45;
         A21[i+45] += y21 * x45;
         A22[i+45] += y22 * x45;
         A23[i+45] += y23 * x45;
         A0[i+46] += y0 * x46;
         A1[i+46] += y1 * x46;
         A2[i+46] += y2 * x46;
         A3[i+46] += y3 * x46;
         A4[i+46] += y4 * x46;
         A5[i+46] += y5 * x46;
         A6[i+46] += y6 * x46;
         A7[i+46] += y7 * x46;
         A8[i+46] += y8 * x46;
         A9[i+46] += y9 * x46;
         A10[i+46] += y10 * x46;
         A11[i+46] += y11 * x46;
         A12[i+46] += y12 * x46;
         A13[i+46] += y13 * x46;
         A14[i+46] += y14 * x46;
         A15[i+46] += y15 * x46;
         A16[i+46] += y16 * x46;
         A17[i+46] += y17 * x46;
         A18[i+46] += y18 * x46;
         A19[i+46] += y19 * x46;
         A20[i+46] += y20 * x46;
         A21[i+46] += y21 * x46;
         A22[i+46] += y22 * x46;
         A23[i+46] += y23 * x46;
         A0[i+47] += y0 * x47;
         A1[i+47] += y1 * x47;
         A2[i+47] += y2 * x47;
         A3[i+47] += y3 * x47;
         A4[i+47] += y4 * x47;
         A5[i+47] += y5 * x47;
         A6[i+47] += y6 * x47;
         A7[i+47] += y7 * x47;
         A8[i+47] += y8 * x47;
         A9[i+47] += y9 * x47;
         A10[i+47] += y10 * x47;
         A11[i+47] += y11 * x47;
         A12[i+47] += y12 * x47;
         A13[i+47] += y13 * x47;
         A14[i+47] += y14 * x47;
         A15[i+47] += y15 * x47;
         A16[i+47] += y16 * x47;
         A17[i+47] += y17 * x47;
         A18[i+47] += y18 * x47;
         A19[i+47] += y19 * x47;
         A20[i+47] += y20 * x47;
         A21[i+47] += y21 * x47;
         A22[i+47] += y22 * x47;
         A23[i+47] += y23 * x47;
         A0[i+48] += y0 * x48;
         prefA(A0);
         A1[i+48] += y1 * x48;
         prefA(A1);
         A2[i+48] += y2 * x48;
         prefA(A2);
         A3[i+48] += y3 * x48;
         prefA(A3);
         A4[i+48] += y4 * x48;
         prefA(A4);
         A5[i+48] += y5 * x48;
         prefA(A5);
         A6[i+48] += y6 * x48;
         prefA(A6);
         A7[i+48] += y7 * x48;
         prefA(A7);
         A8[i+48] += y8 * x48;
         prefA(A8);
         A9[i+48] += y9 * x48;
         prefA(A9);
         A10[i+48] += y10 * x48;
         prefA(A10);
         A11[i+48] += y11 * x48;
         prefA(A11);
         A12[i+48] += y12 * x48;
         prefA(A12);
         A13[i+48] += y13 * x48;
         prefA(A13);
         A14[i+48] += y14 * x48;
         prefA(A14);
         A15[i+48] += y15 * x48;
         prefA(A15);
         A16[i+48] += y16 * x48;
         prefA(A16);
         A17[i+48] += y17 * x48;
         prefA(A17);
         A18[i+48] += y18 * x48;
         prefA(A18);
         A19[i+48] += y19 * x48;
         prefA(A19);
         A20[i+48] += y20 * x48;
         prefA(A20);
         A21[i+48] += y21 * x48;
         prefA(A21);
         A22[i+48] += y22 * x48;
         prefA(A22);
         A23[i+48] += y23 * x48;
         prefA(A23);
         A0[i+49] += y0 * x49;
         A1[i+49] += y1 * x49;
         A2[i+49] += y2 * x49;
         A3[i+49] += y3 * x49;
         A4[i+49] += y4 * x49;
         A5[i+49] += y5 * x49;
         A6[i+49] += y6 * x49;
         A7[i+49] += y7 * x49;
         A8[i+49] += y8 * x49;
         A9[i+49] += y9 * x49;
         A10[i+49] += y10 * x49;
         A11[i+49] += y11 * x49;
         A12[i+49] += y12 * x49;
         A13[i+49] += y13 * x49;
         A14[i+49] += y14 * x49;
         A15[i+49] += y15 * x49;
         A16[i+49] += y16 * x49;
         A17[i+49] += y17 * x49;
         A18[i+49] += y18 * x49;
         A19[i+49] += y19 * x49;
         A20[i+49] += y20 * x49;
         A21[i+49] += y21 * x49;
         A22[i+49] += y22 * x49;
         A23[i+49] += y23 * x49;
         A0[i+50] += y0 * x50;
         A1[i+50] += y1 * x50;
         A2[i+50] += y2 * x50;
         A3[i+50] += y3 * x50;
         A4[i+50] += y4 * x50;
         A5[i+50] += y5 * x50;
         A6[i+50] += y6 * x50;
         A7[i+50] += y7 * x50;
         A8[i+50] += y8 * x50;
         A9[i+50] += y9 * x50;
         A10[i+50] += y10 * x50;
         A11[i+50] += y11 * x50;
         A12[i+50] += y12 * x50;
         A13[i+50] += y13 * x50;
         A14[i+50] += y14 * x50;
         A15[i+50] += y15 * x50;
         A16[i+50] += y16 * x50;
         A17[i+50] += y17 * x50;
         A18[i+50] += y18 * x50;
         A19[i+50] += y19 * x50;
         A20[i+50] += y20 * x50;
         A21[i+50] += y21 * x50;
         A22[i+50] += y22 * x50;
         A23[i+50] += y23 * x50;
         A0[i+51] += y0 * x51;
         A1[i+51] += y1 * x51;
         A2[i+51] += y2 * x51;
         A3[i+51] += y3 * x51;
         A4[i+51] += y4 * x51;
         A5[i+51] += y5 * x51;
         A6[i+51] += y6 * x51;
         A7[i+51] += y7 * x51;
         A8[i+51] += y8 * x51;
         A9[i+51] += y9 * x51;
         A10[i+51] += y10 * x51;
         A11[i+51] += y11 * x51;
         A12[i+51] += y12 * x51;
         A13[i+51] += y13 * x51;
         A14[i+51] += y14 * x51;
         A15[i+51] += y15 * x51;
         A16[i+51] += y16 * x51;
         A17[i+51] += y17 * x51;
         A18[i+51] += y18 * x51;
         A19[i+51] += y19 * x51;
         A20[i+51] += y20 * x51;
         A21[i+51] += y21 * x51;
         A22[i+51] += y22 * x51;
         A23[i+51] += y23 * x51;
         A0[i+52] += y0 * x52;
         A1[i+52] += y1 * x52;
         A2[i+52] += y2 * x52;
         A3[i+52] += y3 * x52;
         A4[i+52] += y4 * x52;
         A5[i+52] += y5 * x52;
         A6[i+52] += y6 * x52;
         A7[i+52] += y7 * x52;
         A8[i+52] += y8 * x52;
         A9[i+52] += y9 * x52;
         A10[i+52] += y10 * x52;
         A11[i+52] += y11 * x52;
         A12[i+52] += y12 * x52;
         A13[i+52] += y13 * x52;
         A14[i+52] += y14 * x52;
         A15[i+52] += y15 * x52;
         A16[i+52] += y16 * x52;
         A17[i+52] += y17 * x52;
         A18[i+52] += y18 * x52;
         A19[i+52] += y19 * x52;
         A20[i+52] += y20 * x52;
         A21[i+52] += y21 * x52;
         A22[i+52] += y22 * x52;
         A23[i+52] += y23 * x52;
         A0[i+53] += y0 * x53;
         A1[i+53] += y1 * x53;
         A2[i+53] += y2 * x53;
         A3[i+53] += y3 * x53;
         A4[i+53] += y4 * x53;
         A5[i+53] += y5 * x53;
         A6[i+53] += y6 * x53;
         A7[i+53] += y7 * x53;
         A8[i+53] += y8 * x53;
         A9[i+53] += y9 * x53;
         A10[i+53] += y10 * x53;
         A11[i+53] += y11 * x53;
         A12[i+53] += y12 * x53;
         A13[i+53] += y13 * x53;
         A14[i+53] += y14 * x53;
         A15[i+53] += y15 * x53;
         A16[i+53] += y16 * x53;
         A17[i+53] += y17 * x53;
         A18[i+53] += y18 * x53;
         A19[i+53] += y19 * x53;
         A20[i+53] += y20 * x53;
         A21[i+53] += y21 * x53;
         A22[i+53] += y22 * x53;
         A23[i+53] += y23 * x53;
         A0[i+54] += y0 * x54;
         A1[i+54] += y1 * x54;
         A2[i+54] += y2 * x54;
         A3[i+54] += y3 * x54;
         A4[i+54] += y4 * x54;
         A5[i+54] += y5 * x54;
         A6[i+54] += y6 * x54;
         A7[i+54] += y7 * x54;
         A8[i+54] += y8 * x54;
         A9[i+54] += y9 * x54;
         A10[i+54] += y10 * x54;
         A11[i+54] += y11 * x54;
         A12[i+54] += y12 * x54;
         A13[i+54] += y13 * x54;
         A14[i+54] += y14 * x54;
         A15[i+54] += y15 * x54;
         A16[i+54] += y16 * x54;
         A17[i+54] += y17 * x54;
         A18[i+54] += y18 * x54;
         A19[i+54] += y19 * x54;
         A20[i+54] += y20 * x54;
         A21[i+54] += y21 * x54;
         A22[i+54] += y22 * x54;
         A23[i+54] += y23 * x54;
         A0[i+55] += y0 * x55;
         A1[i+55] += y1 * x55;
         A2[i+55] += y2 * x55;
         A3[i+55] += y3 * x55;
         A4[i+55] += y4 * x55;
         A5[i+55] += y5 * x55;
         A6[i+55] += y6 * x55;
         A7[i+55] += y7 * x55;
         A8[i+55] += y8 * x55;
         A9[i+55] += y9 * x55;
         A10[i+55] += y10 * x55;
         A11[i+55] += y11 * x55;
         A12[i+55] += y12 * x55;
         A13[i+55] += y13 * x55;
         A14[i+55] += y14 * x55;
         A15[i+55] += y15 * x55;
         A16[i+55] += y16 * x55;
         A17[i+55] += y17 * x55;
         A18[i+55] += y18 * x55;
         A19[i+55] += y19 * x55;
         A20[i+55] += y20 * x55;
         A21[i+55] += y21 * x55;
         A22[i+55] += y22 * x55;
         A23[i+55] += y23 * x55;
         A0[i+56] += y0 * x56;
         A1[i+56] += y1 * x56;
         A2[i+56] += y2 * x56;
         A3[i+56] += y3 * x56;
         A4[i+56] += y4 * x56;
         A5[i+56] += y5 * x56;
         A6[i+56] += y6 * x56;
         A7[i+56] += y7 * x56;
         A8[i+56] += y8 * x56;
         A9[i+56] += y9 * x56;
         A10[i+56] += y10 * x56;
         A11[i+56] += y11 * x56;
         A12[i+56] += y12 * x56;
         A13[i+56] += y13 * x56;
         A14[i+56] += y14 * x56;
         A15[i+56] += y15 * x56;
         A16[i+56] += y16 * x56;
         A17[i+56] += y17 * x56;
         A18[i+56] += y18 * x56;
         A19[i+56] += y19 * x56;
         A20[i+56] += y20 * x56;
         A21[i+56] += y21 * x56;
         A22[i+56] += y22 * x56;
         A23[i+56] += y23 * x56;
         A0[i+57] += y0 * x57;
         A1[i+57] += y1 * x57;
         A2[i+57] += y2 * x57;
         A3[i+57] += y3 * x57;
         A4[i+57] += y4 * x57;
         A5[i+57] += y5 * x57;
         A6[i+57] += y6 * x57;
         A7[i+57] += y7 * x57;
         A8[i+57] += y8 * x57;
         A9[i+57] += y9 * x57;
         A10[i+57] += y10 * x57;
         A11[i+57] += y11 * x57;
         A12[i+57] += y12 * x57;
         A13[i+57] += y13 * x57;
         A14[i+57] += y14 * x57;
         A15[i+57] += y15 * x57;
         A16[i+57] += y16 * x57;
         A17[i+57] += y17 * x57;
         A18[i+57] += y18 * x57;
         A19[i+57] += y19 * x57;
         A20[i+57] += y20 * x57;
         A21[i+57] += y21 * x57;
         A22[i+57] += y22 * x57;
         A23[i+57] += y23 * x57;
         A0[i+58] += y0 * x58;
         A1[i+58] += y1 * x58;
         A2[i+58] += y2 * x58;
         A3[i+58] += y3 * x58;
         A4[i+58] += y4 * x58;
         A5[i+58] += y5 * x58;
         A6[i+58] += y6 * x58;
         A7[i+58] += y7 * x58;
         A8[i+58] += y8 * x58;
         A9[i+58] += y9 * x58;
         A10[i+58] += y10 * x58;
         A11[i+58] += y11 * x58;
         A12[i+58] += y12 * x58;
         A13[i+58] += y13 * x58;
         A14[i+58] += y14 * x58;
         A15[i+58] += y15 * x58;
         A16[i+58] += y16 * x58;
         A17[i+58] += y17 * x58;
         A18[i+58] += y18 * x58;
         A19[i+58] += y19 * x58;
         A20[i+58] += y20 * x58;
         A21[i+58] += y21 * x58;
         A22[i+58] += y22 * x58;
         A23[i+58] += y23 * x58;
         A0[i+59] += y0 * x59;
         A1[i+59] += y1 * x59;
         A2[i+59] += y2 * x59;
         A3[i+59] += y3 * x59;
         A4[i+59] += y4 * x59;
         A5[i+59] += y5 * x59;
         A6[i+59] += y6 * x59;
         A7[i+59] += y7 * x59;
         A8[i+59] += y8 * x59;
         A9[i+59] += y9 * x59;
         A10[i+59] += y10 * x59;
         A11[i+59] += y11 * x59;
         A12[i+59] += y12 * x59;
         A13[i+59] += y13 * x59;
         A14[i+59] += y14 * x59;
         A15[i+59] += y15 * x59;
         A16[i+59] += y16 * x59;
         A17[i+59] += y17 * x59;
         A18[i+59] += y18 * x59;
         A19[i+59] += y19 * x59;
         A20[i+59] += y20 * x59;
         A21[i+59] += y21 * x59;
         A22[i+59] += y22 * x59;
         A23[i+59] += y23 * x59;
         A0[i+60] += y0 * x60;
         A1[i+60] += y1 * x60;
         A2[i+60] += y2 * x60;
         A3[i+60] += y3 * x60;
         A4[i+60] += y4 * x60;
         A5[i+60] += y5 * x60;
         A6[i+60] += y6 * x60;
         A7[i+60] += y7 * x60;
         A8[i+60] += y8 * x60;
         A9[i+60] += y9 * x60;
         A10[i+60] += y10 * x60;
         A11[i+60] += y11 * x60;
         A12[i+60] += y12 * x60;
         A13[i+60] += y13 * x60;
         A14[i+60] += y14 * x60;
         A15[i+60] += y15 * x60;
         A16[i+60] += y16 * x60;
         A17[i+60] += y17 * x60;
         A18[i+60] += y18 * x60;
         A19[i+60] += y19 * x60;
         A20[i+60] += y20 * x60;
         A21[i+60] += y21 * x60;
         A22[i+60] += y22 * x60;
         A23[i+60] += y23 * x60;
         A0[i+61] += y0 * x61;
         A1[i+61] += y1 * x61;
         A2[i+61] += y2 * x61;
         A3[i+61] += y3 * x61;
         A4[i+61] += y4 * x61;
         A5[i+61] += y5 * x61;
         A6[i+61] += y6 * x61;
         A7[i+61] += y7 * x61;
         A8[i+61] += y8 * x61;
         A9[i+61] += y9 * x61;
         A10[i+61] += y10 * x61;
         A11[i+61] += y11 * x61;
         A12[i+61] += y12 * x61;
         A13[i+61] += y13 * x61;
         A14[i+61] += y14 * x61;
         A15[i+61] += y15 * x61;
         A16[i+61] += y16 * x61;
         A17[i+61] += y17 * x61;
         A18[i+61] += y18 * x61;
         A19[i+61] += y19 * x61;
         A20[i+61] += y20 * x61;
         A21[i+61] += y21 * x61;
         A22[i+61] += y22 * x61;
         A23[i+61] += y23 * x61;
         A0[i+62] += y0 * x62;
         A1[i+62] += y1 * x62;
         A2[i+62] += y2 * x62;
         A3[i+62] += y3 * x62;
         A4[i+62] += y4 * x62;
         A5[i+62] += y5 * x62;
         A6[i+62] += y6 * x62;
         A7[i+62] += y7 * x62;
         A8[i+62] += y8 * x62;
         A9[i+62] += y9 * x62;
         A10[i+62] += y10 * x62;
         A11[i+62] += y11 * x62;
         A12[i+62] += y12 * x62;
         A13[i+62] += y13 * x62;
         A14[i+62] += y14 * x62;
         A15[i+62] += y15 * x62;
         A16[i+62] += y16 * x62;
         A17[i+62] += y17 * x62;
         A18[i+62] += y18 * x62;
         A19[i+62] += y19 * x62;
         A20[i+62] += y20 * x62;
         A21[i+62] += y21 * x62;
         A22[i+62] += y22 * x62;
         A23[i+62] += y23 * x62;
         A0[i+63] += y0 * x63;
         A1[i+63] += y1 * x63;
         A2[i+63] += y2 * x63;
         A3[i+63] += y3 * x63;
         A4[i+63] += y4 * x63;
         A5[i+63] += y5 * x63;
         A6[i+63] += y6 * x63;
         A7[i+63] += y7 * x63;
         A8[i+63] += y8 * x63;
         A9[i+63] += y9 * x63;
         A10[i+63] += y10 * x63;
         A11[i+63] += y11 * x63;
         A12[i+63] += y12 * x63;
         A13[i+63] += y13 * x63;
         A14[i+63] += y14 * x63;
         A15[i+63] += y15 * x63;
         A16[i+63] += y16 * x63;
         A17[i+63] += y17 * x63;
         A18[i+63] += y18 * x63;
         A19[i+63] += y19 * x63;
         A20[i+63] += y20 * x63;
         A21[i+63] += y21 * x63;
         A22[i+63] += y22 * x63;
         A23[i+63] += y23 * x63;
      }
      for (i=M64; i < M; i++)
      {
         const register float x0 = X[i];
         A0[i] += y0 * x0;
         A1[i] += y1 * x0;
         A2[i] += y2 * x0;
         A3[i] += y3 * x0;
         A4[i] += y4 * x0;
         A5[i] += y5 * x0;
         A6[i] += y6 * x0;
         A7[i] += y7 * x0;
         A8[i] += y8 * x0;
         A9[i] += y9 * x0;
         A10[i] += y10 * x0;
         A11[i] += y11 * x0;
         A12[i] += y12 * x0;
         A13[i] += y13 * x0;
         A14[i] += y14 * x0;
         A15[i] += y15 * x0;
         A16[i] += y16 * x0;
         A17[i] += y17 * x0;
         A18[i] += y18 * x0;
         A19[i] += y19 * x0;
         A20[i] += y20 * x0;
         A21[i] += y21 * x0;
         A22[i] += y22 * x0;
         A23[i] += y23 * x0;
      }
   }
/*
 * Do remaining columns with NU=1 cleanup
 */
   for (j=N-N24; j; j--, A += lda, Y++)
   {
      float *A0=A;
      const register float y0=Y[0];
      ATL_INT i;
      prefY(Y+1+1-1);
      for (i=0; i < M64; i += 64)
      {
         const register float x0=X[i+0], x1=X[i+1], x2=X[i+2], x3=X[i+3],
                              x4=X[i+4], x5=X[i+5], x6=X[i+6], x7=X[i+7],
                              x8=X[i+8], x9=X[i+9], x10=X[i+10], x11=X[i+11],
                              x12=X[i+12], x13=X[i+13], x14=X[i+14],
                              x15=X[i+15], x16=X[i+16], x17=X[i+17],
                              x18=X[i+18], x19=X[i+19], x20=X[i+20],
                              x21=X[i+21], x22=X[i+22], x23=X[i+23],
                              x24=X[i+24], x25=X[i+25], x26=X[i+26],
                              x27=X[i+27], x28=X[i+28], x29=X[i+29],
                              x30=X[i+30], x31=X[i+31], x32=X[i+32],
                              x33=X[i+33], x34=X[i+34], x35=X[i+35],
                              x36=X[i+36], x37=X[i+37], x38=X[i+38],
                              x39=X[i+39], x40=X[i+40], x41=X[i+41],
                              x42=X[i+42], x43=X[i+43], x44=X[i+44],
                              x45=X[i+45], x46=X[i+46], x47=X[i+47],
                              x48=X[i+48], x49=X[i+49], x50=X[i+50],
                              x51=X[i+51], x52=X[i+52], x53=X[i+53],
                              x54=X[i+54], x55=X[i+55], x56=X[i+56],
                              x57=X[i+57], x58=X[i+58], x59=X[i+59],
                              x60=X[i+60], x61=X[i+61], x62=X[i+62],
                              x63=X[i+63];

         prefX(X);
         A0[i+0] += y0 * x0;
         prefA(A0);
         A0[i+1] += y0 * x1;
         A0[i+2] += y0 * x2;
         A0[i+3] += y0 * x3;
         A0[i+4] += y0 * x4;
         A0[i+5] += y0 * x5;
         A0[i+6] += y0 * x6;
         A0[i+7] += y0 * x7;
         A0[i+8] += y0 * x8;
         A0[i+9] += y0 * x9;
         A0[i+10] += y0 * x10;
         A0[i+11] += y0 * x11;
         A0[i+12] += y0 * x12;
         A0[i+13] += y0 * x13;
         A0[i+14] += y0 * x14;
         A0[i+15] += y0 * x15;
         A0[i+16] += y0 * x16;
         prefA(A0);
         A0[i+17] += y0 * x17;
         A0[i+18] += y0 * x18;
         A0[i+19] += y0 * x19;
         A0[i+20] += y0 * x20;
         A0[i+21] += y0 * x21;
         A0[i+22] += y0 * x22;
         A0[i+23] += y0 * x23;
         A0[i+24] += y0 * x24;
         A0[i+25] += y0 * x25;
         A0[i+26] += y0 * x26;
         A0[i+27] += y0 * x27;
         A0[i+28] += y0 * x28;
         A0[i+29] += y0 * x29;
         A0[i+30] += y0 * x30;
         A0[i+31] += y0 * x31;
         A0[i+32] += y0 * x32;
         prefA(A0);
         A0[i+33] += y0 * x33;
         A0[i+34] += y0 * x34;
         A0[i+35] += y0 * x35;
         A0[i+36] += y0 * x36;
         A0[i+37] += y0 * x37;
         A0[i+38] += y0 * x38;
         A0[i+39] += y0 * x39;
         A0[i+40] += y0 * x40;
         A0[i+41] += y0 * x41;
         A0[i+42] += y0 * x42;
         A0[i+43] += y0 * x43;
         A0[i+44] += y0 * x44;
         A0[i+45] += y0 * x45;
         A0[i+46] += y0 * x46;
         A0[i+47] += y0 * x47;
         A0[i+48] += y0 * x48;
         prefA(A0);
         A0[i+49] += y0 * x49;
         A0[i+50] += y0 * x50;
         A0[i+51] += y0 * x51;
         A0[i+52] += y0 * x52;
         A0[i+53] += y0 * x53;
         A0[i+54] += y0 * x54;
         A0[i+55] += y0 * x55;
         A0[i+56] += y0 * x56;
         A0[i+57] += y0 * x57;
         A0[i+58] += y0 * x58;
         A0[i+59] += y0 * x59;
         A0[i+60] += y0 * x60;
         A0[i+61] += y0 * x61;
         A0[i+62] += y0 * x62;
         A0[i+63] += y0 * x63;
      }
      for (i=M64; i < M; i++)
      {
         const register float x0 = X[i];
         A0[i] += y0 * x0;
      }
   }
}
